summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/pkgcontentspage.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /umbrello/umbrello/dialogs/pkgcontentspage.h
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/dialogs/pkgcontentspage.h')
-rw-r--r--umbrello/umbrello/dialogs/pkgcontentspage.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/umbrello/umbrello/dialogs/pkgcontentspage.h b/umbrello/umbrello/dialogs/pkgcontentspage.h
index b95e5348..ef6faff1 100644
--- a/umbrello/umbrello/dialogs/pkgcontentspage.h
+++ b/umbrello/umbrello/dialogs/pkgcontentspage.h
@@ -27,14 +27,15 @@
*/
class PkgContentsPage : public TQWidget {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructs an instance of PkgContentsPage.
*
* @param parent The parent of the page.
* @param pkg The UMLPackage being represented.
*/
- PkgContentsPage(TQWidget *parent, UMLPackage *pkg);
+ PkgContentsPage(TQWidget *tqparent, UMLPackage *pkg);
/**
* Standard destructor.
@@ -27,14 +27,15 @@
* Constructs an instance of PkgContentsPage.
*
- * @param parent The parent of the page.
+ * @param tqparent The tqparent of the page.
* @param pkg The UMLPackage being represented.
*/